package com.bweb.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.config.PayloService;
import com.hai.config.PetroConfig;
import com.hai.config.PetroCouponConfig;
import com.hai.entity.ApiCoupon;
import com.hai.model.ResponseData;
import com.hai.openApi.service.ApiBlxCouponService;
import com.hai.openApi.service.ApiCouponService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

@Controller
@RequestMapping(value = "/apiCoupon")
@Api(value = "外部卡券查询")
public class ApiCouponController {

    private static Logger log = LoggerFactory.getLogger(HighDiscountPackageController.class);

    @Resource
    private ApiBlxCouponService apiBlxCouponService;

    @Resource
    private ApiCouponService apiCouponService;

    @Resource
    private PetroConfig petroConfig;


    @RequestMapping(value = "/getBlxCouponList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取比邻星停车券列表")
    public ResponseData getBlxCouponList( @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                          @RequestParam(name = "pageSize", required = true) Integer pageSize) {
        try {

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(apiBlxCouponService.getBlxCouponList(new HashMap<>())));

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> getDiscountPackageList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/synCouponRule", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取中石油卡券")
    public ResponseData synCouponRule(@RequestParam(name = "type", required = true) Integer type) {
        try {

            if (type == 4) {
                JSONObject jsonObject = PetroCouponConfig.getCouponList();
                JSONArray array = jsonObject.getJSONArray("data");
                List<JSONObject> list = new ArrayList<>();

                for (int i = 0; i < array.size(); i++) {
                    JSONObject object = array.getJSONObject(i);
                    object.put("alias" , object.getString("reqCode"));
                    object.put("title" , object.getString("tplName"));
                    object.put("qty" , object.getString("ticketBalance"));
                    object.put("faceValue" , object.getBigDecimal("tplAmount").divide(new BigDecimal(100)));
                    object.put("bizTypeDesc" , "汽油券");
                    object.put("validDate" , "180");
                    list.add(object);
                }
                return ResponseMsgUtil.success(list);

            } else {
                PetroConfig.init(type);

                JSONObject jsonObject = petroConfig.synCouponRule();

                if (jsonObject.getString("resultCode").equals("0000")) {
                    String data = PetroConfig.decrypt(jsonObject.getString("jsonResult"));
                    JSONArray jsonArray = JSONArray.parseArray(data);

                    ApiCoupon apiCoupon;

                    for (int i = 0; i < jsonArray.size(); i++) {

                        JSONObject object = jsonArray.getJSONObject(i);
                        apiCoupon = apiCouponService.findCoupon(object.getString("alias"));

                        if (apiCoupon == null ) {
                            apiCoupon = new ApiCoupon();
                            apiCoupon.setCode(object.getString("alias"));
                            apiCoupon.setDesc(object.getString("declare"));
                            apiCoupon.setGoodsType(object.getString("bizType"));
                            apiCoupon.setName(object.getString("title"));
                            apiCoupon.setValidType(object.getInteger("validType"));
                            if (object.getInteger("validType") == 1) {
                                apiCoupon.setValidDate(object.getDate("validDate"));
                            }
                            apiCoupon.setEffectiveDays(object.getInteger("validDate"));
                            apiCoupon.setImg(object.getString("img"));
                            apiCoupon.setCreateTime(new Date());
                            apiCoupon.setUpdateTime(new Date());
                            apiCoupon.setStatus(1);
                            apiCoupon.setType(type);
                            apiCoupon.setPrice(object.getInteger("faceValue"));
                            apiCouponService.insertCoupon(apiCoupon);
                        } else {
                            apiCoupon.setCode(object.getString("alias"));
                            apiCoupon.setDesc(object.getString("declare"));
                            apiCoupon.setGoodsType(object.getString("bizType"));
                            apiCoupon.setName(object.getString("title"));
                            apiCoupon.setValidType(object.getInteger("validType"));
                            if (object.getInteger("validType") == 1) {
                                apiCoupon.setValidDate(object.getDate("validDate"));
                            }
                            apiCoupon.setEffectiveDays(object.getInteger("validDate"));
                            apiCoupon.setImg(object.getString("img"));
                            apiCoupon.setUpdateTime(new Date());
                            apiCoupon.setStatus(1);
                            apiCoupon.setType(type);
                            apiCoupon.setPrice(object.getInteger("faceValue"));
                            apiCouponService.editCoupon(apiCoupon);
                        }
                    }


                    return ResponseMsgUtil.success(jsonArray);
            }


            }
            return ResponseMsgUtil.success("请求失败");

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> getDiscountPackageList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
