package com.cweb.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.config.PetroConfig;
import com.hai.entity.HighCouponCodeOther;
import com.hai.entity.HighOrder;
import com.hai.entity.HighUser;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value = "/couponCodeOther")
@Api(value = "用户接口")
public class HighCouponCodeOtherController {

    private static Logger log = LoggerFactory.getLogger(HighCouponCodeOtherController.class);

    @Resource
    private HighCouponCodeOtherService highCouponCodeOtherService;

    @Resource
    private HighOrderService highOrderService;

    @Resource
    private PetroConfig petroConfig;

    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询卡券码列表")
    public ResponseData getList(@RequestParam(name = "type", required = true) Integer type,
                                @RequestParam(name = "orderId", required = false) Long orderId,
                                @RequestParam(name = "childOrderId", required = false) Long childOrderId) {
        try {

            Map<String,Object> map = new HashMap<>();
            map.put("type", type);
            map.put("orderId", orderId);
            map.put("childOrderId", childOrderId);

            return ResponseMsgUtil.success(highCouponCodeOtherService.getList(map));

        } catch (Exception e) {
            log.error("HighCouponCodeOtherController --> getList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/unusedCoupons", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取核销码")
    public ResponseData unusedCoupons(@RequestParam(name = "orderId", required = false) Long orderId) {
        try {

            Map<String,Object> map = new HashMap<>();
            map.put("orderId", orderId);

            List<HighCouponCodeOther> highCouponCodeOtherServiceList = highCouponCodeOtherService.getList(map);

            if (highCouponCodeOtherServiceList.isEmpty()) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未找到核销码！");
            }

            HighCouponCodeOther couponCodeOther = highCouponCodeOtherServiceList.get(0);

            HighOrder highOrder = highOrderService.getOrderById(orderId);
            PetroConfig.init(2);
            JSONObject jsonObject = petroConfig.getCheckCode(couponCodeOther.getCouNo() , highOrder.getMemPhone());
            String data = PetroConfig.decrypt(jsonObject.getString("jsonResult"));
            JSONObject object = JSONObject.parseObject(data);
            return ResponseMsgUtil.success(object);

        } catch (Exception e) {
            log.error("HighCouponCodeOtherController --> getList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/cancelCouponsYt", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "撤销电子券")
    public ResponseData cancelCouponsYt(@RequestParam(name = "orderId", required = false) Long orderId) {
        try {

            Map<String,Object> map = new HashMap<>();
            map.put("orderId", orderId);

            List<HighCouponCodeOther> highCouponCodeOtherServiceList = highCouponCodeOtherService.getList(map);

            HighCouponCodeOther couponCodeOther = highCouponCodeOtherServiceList.get(0);

            HighOrder highOrder = highOrderService.getOrderById(orderId);
            PetroConfig.init(2);
            JSONObject jsonObject = petroConfig.cancelCouponsYt(couponCodeOther.getCouNo() , highOrder.getMemPhone());
            String data = PetroConfig.decrypt(jsonObject.getString("jsonResult"));
            return ResponseMsgUtil.success(data);

        } catch (Exception e) {
            log.error("HighCouponCodeOtherController --> getList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/cancelCouponsYtApi", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "撤销电子券")
    public ResponseData cancelCouponsYtApi(@RequestParam(name = "orderId", required = false) Long orderId) {
        try {

            HighOrder highOrder = highOrderService.getOrderById(orderId);
            PetroConfig.init(2);
            JSONObject jsonObject = petroConfig.cancelCouponsYt(highOrder.getHighChildOrderList().get(0).getExt6() , highOrder.getMemPhone());
            String data = PetroConfig.decrypt(jsonObject.getString("jsonResult"));
            return ResponseMsgUtil.success(data);

        } catch (Exception e) {
            log.error("HighCouponCodeOtherController --> getList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


}
