package com.cweb.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.Base64Util;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.AESEncodeUtil;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.*;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

@Controller
@RequestMapping(value = "/discountPackage")
@Api(value = "优惠券包接口")
public class HighDiscountPackageController {

    private static Logger log = LoggerFactory.getLogger(HighDiscountPackageController.class);

    @Resource
    private HighDiscountPackageService highDiscountPackageService;

    @Resource
    private HighDiscountPackageDetailsService highDiscountPackageDetailsService;

    @Resource
    private HighDiscountService highDiscountService;


    @Resource
    private CommonService commonService;

    @Resource
    private HighDiscountPackageAgentService discountPackageAgentService;

    @Resource
    private BsTemporaryServices bsTemporaryServices;

    @Autowired
    private RedisTemplate redisTemplate;

    @Resource
    private UserCenter userCenter;

    @Resource
    private HighUserService userService;


    @RequestMapping(value = "/getDiscountPackageList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取优惠券包列表")
    public ResponseData getDiscountPackageList(@RequestParam(name = "companyId", required = true) String companyId,
                                               @RequestParam(name = "usingAttribution", required = false) Integer usingAttribution,
                                               @RequestParam(name = "title", required = false) String title,
                                               @RequestParam(name = "showLabel", required = false) String showLabel,
                                               @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                               @RequestParam(name = "pageSize", required = true) Integer pageSize) {
        try {

            Map<String, Object> map = new HashMap<>();
            map.put("companyId", companyId);
            map.put("usingAttribution", usingAttribution);
            map.put("title" , title);
            map.put("showLabel" , showLabel);
            map.put("salesType" , 1);
            map.put("status" , 1);
            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highDiscountPackageService.getDiscountPackageList(map)));

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> getDiscountPackageList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getDiscountPackageDetail", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取优惠券包详情")
    public ResponseData getDiscountPackageDetail(@RequestParam(name = "packageId", required = true) Integer packageId) {
        try {

            Map<String, Object> map = new HashMap<>();

            HighDiscountPackage discountPackage = highDiscountPackageService.findDiscountPackageById(packageId);
            if (discountPackage != null) {
                map.put("packageDetail", discountPackage);
                // 查询包内的优惠券
                List<HighDiscountPackageDetails> detailsList = highDiscountPackageDetailsService.getDetailByPackage(packageId);
                for (HighDiscountPackageDetails discount: detailsList) {
                    discount.setDiscountDetail(highDiscountService.getDiscountById(Long.parseLong(discount.getDiscountId().toString())));
                }
                map.put("msg", commonService.findSecConfigByType("DISCOUNT_PACKAGE_DETAIL").getCodeValue());
                map.put("discountList", detailsList);
                return ResponseMsgUtil.success(map);
            }

            return ResponseMsgUtil.success(null);

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> getDiscountPackageDetail() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/receivePackageTemporary", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "券包临时领取")
    public ResponseData receivePackageTemporary(@RequestParam(name = "packageId", required = true) Integer packageId,
                                               @RequestParam(name = "openId", required = true) String openId,
                                               @RequestParam(name = "agentId", required = true) Long agentId) {

        String key = "receivePackage_" + packageId + "_" + agentId;

        Map<String, Object> param = new HashMap<>();
        param.put("openIdH5", openId);
        List<HighUser> userList = userService.getUserList(param);


        try {
            // 分布式锁占坑
            Boolean lock = redisTemplate.opsForValue().setIfAbsent(key, openId);

            if (Boolean.TRUE.equals(lock)) {

                Map<String , Object> map = new HashMap<>();
                map.put("agentId" , agentId);
                map.put("discountPackageId" , packageId);
                map.put("status" , 1);

                List<HighDiscountPackageAgentCode> list = discountPackageAgentService.getDiscountPackageAgentCodeList(map);

                if (list.size() == 0) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未查询当相关内容！");
                }

                HighDiscountPackageAgentCode discountPackageAgentCode = list.get(0);

                if (list.size() == 0) {
                    log.error("HighDiscountController -> getDiscountByQrCode() error!","当前券包库存不足");
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "当前券包库存不足");
                }

                BsTemporary bsTemporary = bsTemporaryServices.findByCode(openId , 7);

                if (bsTemporary != null) {
                    if (userList.size() > 0) {
                        HighUser user = userList.get(0);
                        if (StringUtils.isNotBlank(user.getPhone())) {
                            highDiscountPackageService.decodeCode(bsTemporary.getCode() , user);
                            return ResponseMsgUtil.success("领取成功！");
                        }
                    }
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "今日已领取，请尽快使用！");
                }

                if (userList.size() > 0) {
                    HighUser user = userList.get(0);
                    if (StringUtils.isNotBlank(user.getPhone())) {
                        highDiscountPackageService.decodeCode(discountPackageAgentCode.getCode() , user);
                        return ResponseMsgUtil.success("领取成功！");
                    }
                }

                bsTemporary = new BsTemporary();
                bsTemporary.setCode(discountPackageAgentCode.getCode());
                bsTemporary.setCreateTime(new Date());
                bsTemporary.setUpdateTime(new Date());
                bsTemporary.setSourceCode(openId);
                bsTemporary.setStatus(1);
                bsTemporary.setType(7);
                bsTemporaryServices.insert(bsTemporary);

                discountPackageAgentCode.setStatus(5);
                discountPackageAgentCode.setUpdateTime(new Date());
                discountPackageAgentService.updateDiscountPackageAgentCode(discountPackageAgentCode);

            } else {
                // 加锁失败，重试
                Thread.sleep(100);
                receivePackageTemporary(packageId , openId , agentId);
            }
            return ResponseMsgUtil.success("领取成功！");

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> getDiscountPackageDetail() error!", e);
            return ResponseMsgUtil.exception(e);
        } finally {
            // 删除key，释放锁
            redisTemplate.delete(key);
        }
    }

    @RequestMapping(value = "/test", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "test")
    public ResponseData test() {
        try {
            // 用户
            List<BsTemporary> list =  bsTemporaryServices.getList(new HashMap<>());

            for (BsTemporary bsTemporary : list) {

                HighDiscountPackageAgentCode discountPackageAgentCode = discountPackageAgentService.findDiscountPackageAgentCode(bsTemporary.getCode());
                discountPackageAgentCode.setStatus(1);
                discountPackageAgentCode.setUpdateTime(new Date());
                discountPackageAgentService.updateDiscountPackageAgentCode(discountPackageAgentCode);
                bsTemporary.setStatus(0);
                bsTemporary.setUpdateTime(new Date());
                bsTemporaryServices.update(bsTemporary);

            }

            return ResponseMsgUtil.success("成功！");

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> giveAway() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value = "/receivePackage", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "领取券包")
    public ResponseData receivePackage(@RequestParam(name = "code", required = false) String code, HttpServletRequest request) {
        try {
            // 用户
            SessionObject sessionObject = userCenter.getSessionObject(request);
            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();


            // 用户
            String jsonData;
            try {
                jsonData = AESEncodeUtil.aesDecrypt(Base64Util.decode(code));
            } catch (Exception e) {
                log.error("HighDiscountController -> getDiscountByQrCode() error!","code解码错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "code解码错误");
            }

            JSONObject jsonObject = JSON.parseObject(jsonData);
            String type = jsonObject.getString("type");

            if (!type.equals("DISCOUNT_PACKAGE")){
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "当前业务不支持！");
            }

            JSONObject object = new JSONObject();
            object.put("code" , code);
            object.put("discountPackageActualId" , jsonObject.getInteger("id"));

            highDiscountPackageService.receivePackage(object , userInfoModel.getHighUser());

            return ResponseMsgUtil.success("领取成功！");

        } catch (Exception e) {
            log.error("HighDiscountPackageController --> giveAway() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }



}
