package com.hai.config;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.utils.HttpsUtils;
import com.hai.common.utils.WxUtils;
import com.hai.entity.EtcCarMsg;
import com.hai.entity.EtcCustMsg;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.context.annotation.Configuration;

import java.io.File;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.*;

/**
 * @serviceName QrCodeUtilsConfig.java
 * @author Sum1Dream
 * @version 1.0.0
 * @Description // Etc申请管理
 * @createTime 09:54 2022/4/13
 **/
@Configuration 
public class EtcService {

    /**
    * @Author Sum1Dream
    * @Name submitCustInfo
    * @Description // 客户信息提交
    * @Date 16:31 2024/3/25
    * @Param etcCustMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject submitCustInfo(EtcCustMsg etcCustMsg) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(String.valueOf(System.currentTimeMillis())));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custName" , etcCustMsg.getCustName());
        jsonObject.put("custIdNo" , etcCustMsg.getCustIdNo());
        jsonObject.put("accountNo" , etcCustMsg.getAccountNo());
        jsonObject.put("bankName" , etcCustMsg.getBankName());
        jsonObject.put("address" , etcCustMsg.getAddress());
        jsonObject.put("phone" , etcCustMsg.getBankPhone());
        jsonObject.put("custAgentIdFront" , convertToBase64(etcCustMsg.getCustAgentIdFront()));
        jsonObject.put("custAgentIdBack" , convertToBase64(etcCustMsg.getCustAgentIdBront()));
        jsonObject.put("bankCard" , convertToBase64(etcCustMsg.getCustAgentIdBront()));
        if (etcCustMsg.getCustId() != null) {
            jsonObject.put("custId" , etcCustMsg.getCustId());
        }
        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/submitCustInfo" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name submitVehInfo
    * @Description // 车辆信息提交接口
    * @Date 11:28 2024/3/26
    * @Param etcCustMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject submitVehInfo(EtcCarMsg etcCarMsg) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("productId" , etcCarMsg.getProductId());
        jsonObject.put("custId" , etcCarMsg.getCustId());
        jsonObject.put("cardVarietyId" , etcCarMsg.getCardVarietyId());

        List<JSONObject> vehInfoList = new ArrayList<>();
        JSONObject vehInfoListObject = new JSONObject();
        vehInfoListObject.put("vehPlateNo" , etcCarMsg.getVehPlateNo());
        vehInfoListObject.put("vehPlateColor" , etcCarMsg.getVehPlateColor());
        vehInfoListObject.put("vehType" , etcCarMsg.getVehType());
        vehInfoListObject.put("wheelsNum" , etcCarMsg.getWheelsNum());
        vehInfoListObject.put("axlesNum" , etcCarMsg.getAxlesNum());
        vehInfoListObject.put("drivLicMainFro" , convertToBase64(etcCarMsg.getDrivlicMainFro()));
        vehInfoListObject.put("drivLicSubFro" , convertToBase64(etcCarMsg.getDrivlicSubFro()));
        vehInfoListObject.put("headStockPhoto" , convertToBase64(etcCarMsg.getHeadStockPhoto()));

        if (etcCarMsg.getVehId() != null) {
            vehInfoListObject.put("vehId" , etcCarMsg.getVehId());
        }
        vehInfoList.add(vehInfoListObject);

        jsonObject.put("vehInfoList" , vehInfoList);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/submitVehInfo" , map);
    }


    /**
    * @Author Sum1Dream
    * @Name getVehStatus
    * @Description // 查询车辆状态
    * @Date 13:54 2024/3/26
    * @Param etcCarMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject getVehStatus(EtcCarMsg etcCarMsg) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , etcCarMsg.getCustId());
        jsonObject.put("vehId" , etcCarMsg.getVehId());

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/getVehStatus" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name sendRealNameCode
    * @Description // 实名认证发送认证码接口
    * @Date 14:14 2024/3/26 
    * @Param JSONObject
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject sendRealNameCode(String custId) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/sendRealNameCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name checkRealNameCode
    * @Description // 实名认证核验验证码接口
    * @Date 14:16 2024/3/26
    * @Param object
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject checkRealNameCode(String custId , String verifyCode) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);
        jsonObject.put("verifyCode" , verifyCode);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/checkRealNameCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name sendSignVerifyCode
    * @Description // 签约验证码发送接口
    * @Date 14:37 2024/3/26 
    * @Param custId 
     * @Param verifyCode  
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject sendSignVerifyCode(String custId) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/sendSignVerifyCode" , map);
    }


    /**
    * @Author Sum1Dream
    * @Name checkSignVerifyCode
    * @Description // 签约验证码核验接口
    * @Date 15:34 2024/3/28 
    * @Param custId 
     * @Param verifyCode  
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject checkSignVerifyCode(String custId , String verifyCode) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);
        jsonObject.put("verifyCode" , verifyCode);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/checkSignVerifyCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name getSignContractTemplate
    * @Description // 获取合同模版
    * @Date 14:31 2024/4/1
    * @Param custId
     * @Param productId
     * @Param cardVarietyId
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject getSignContractTemplate(String custId , Integer productId , Integer cardVarietyId) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);
        jsonObject.put("productId" , productId);
        jsonObject.put("cardVarietyId" , cardVarietyId);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/getSignContractTemplate" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name checkNeedSignWechatWithhold
    * @Description //查看是否需要签约微信代扣
    * @Date 14:31 2024/4/1
    * @Param custId
     * @Param productId
     * @Param cardVarietyId
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject checkNeedSignWechatWithhold(Integer productId  , Integer cardVarietyId , String vehId) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("productId" , productId);
        jsonObject.put("cardVarietyId" , cardVarietyId);
        jsonObject.put("vehId" , vehId);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/checkNeedSignWechatWithhold" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name checkSignWithhold
    * @Description // 是否已签约银行卡代扣
    * @Date 14:42 2024/4/1
    * @Param productId
     * @Param cardVarietyId
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject checkSignWithhold(String custId) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/checkSignWithhold" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name sendSignWithholdCode
    * @Description // 签约银行卡代扣发送验证码
    * @Date 14:45 2024/4/1 
    * @Param object  
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject sendSignWithholdCode(JSONObject object) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , object.getString("custId"));
        jsonObject.put("cardNo" , object.getString("cardNo"));
        jsonObject.put("mobileNo" , object.getString("mobileNo"));
        jsonObject.put("idNo" , object.getString("idNo"));
        jsonObject.put("holderName" , object.getString("holderName"));
        jsonObject.put("cardExpired" , object.getString("cardExpired"));
        jsonObject.put("cardCvv2" , object.getString("cardCvv2"));

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/sendSignWithholdCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name signWithhold
    * @Description // 签约银行卡代扣
    * @Date 14:52 2024/4/1
    * @Param object
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject signWithhold(JSONObject object) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , object.getString("custId"));
        jsonObject.put("bankCardType" , object.getInteger("bankCardType"));
        jsonObject.put("bankName" , object.getString("bankName"));
        jsonObject.put("cardNo" , object.getString("cardNo"));
        jsonObject.put("mobileNo" , object.getString("mobileNo"));
        jsonObject.put("idNo" , object.getString("idNo"));
        jsonObject.put("holderName" , object.getString("holderName"));
        jsonObject.put("cardExpired" , object.getString("cardExpired"));
        jsonObject.put("cardCvv2" , object.getString("cardCvv2"));
        jsonObject.put("verifyCodeNo" , object.getString("verifyCodeNo"));
        jsonObject.put("verifyCode" , object.getString("verifyCode"));

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/signWithhold" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name queryActivateVehicleInfoPage
    * @Description // 查询已经激活车辆
    * @Date 14:12 2024/4/13
    * @Param activeStartTime
     * @Param activeEndTime
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject queryActivateVehicleInfoPage(String activeStartTime , String activeEndTime) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("page" , 1);
        jsonObject.put("limit" , 100000);
        jsonObject.put("activeStartTime" , activeStartTime);
        jsonObject.put("activeEndTime" , activeEndTime);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/queryActivateVehicleInfoPage" , map);
    }

    /**
     * @Author Sum1Dream
     * @Name checkVehPlateNo
     * @Description // 车牌校验接口
     * @Date 14:12 2024/4/13
     * @Param activeStartTime
     * @Param activeEndTime
     * @return com.alibaba.fastjson.JSONObject
     */
    public static JSONObject checkVehPlateNo(String vehPlateNo , String vehPlateColor) throws Exception {
        // 组装数据
        JSONObject map = new JSONObject();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", String.valueOf(System.currentTimeMillis()));
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("vehPlateColor" , vehPlateColor);
        jsonObject.put("vehPlateNo" , vehPlateNo);

        map.put("body" , jsonObject.toJSONString());
        String sign =  WxUtils.generateSignByEtc(map , CommonSysConst.getSysConfig().getNdKey());
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));

        return HttpsUtils.doPost(CommonSysConst.getSysConfig().getNdPostUrl()+"/api/v1/checkVehPlateNo" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name convertToBase64
    * @Description // 转换base64
    * @Date 16:32 2024/3/25
    * @Param imagePath
     * @return java.lang.String
    */
    public static String convertToBase64(String imagePath) throws IOException {
        // 读取图片文件到字节数组
        Path path = new File(CommonSysConst.getSysConfig().getFileUrl() + imagePath).toPath();
        byte[] imageBytes = Files.readAllBytes(path);

        // 将字节数组转换为Base64编码的字符串
        String base64ImageString = Base64.getEncoder().encodeToString(imageBytes);

        // 获取文件扩展名作为数据格式
        String dataFormat = imagePath.substring(imagePath.lastIndexOf('.') + 1);

        // 构建最终的Base64字符串，包含数据格式
        String base64WithDataFormat = "data:image/" + dataFormat + ";base64," + base64ImageString;

        return base64WithDataFormat;


    }







}
