package com.hai.etc.impl;

import com.alibaba.fastjson.JSONObject;
import com.hai.config.EtcService;
import com.hai.dao.EtcCarMsgMapper;
import com.hai.dao.EtcContractOrderMapper;
import com.hai.entity.*;
import com.hai.enum_type.EtcProductEnum;
import com.hai.enum_type.EtcVarietyEnum;
import com.hai.etc.EtcCarMsgService;
import com.hai.order.utils.OrderUtil;
import org.apache.commons.collections4.MapUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("etcCarMsgService")
public class EtcCarMsgServiceImpl implements EtcCarMsgService {

    @Resource
    private EtcCarMsgMapper etcCarMsgMapper;

    @Resource
    private EtcContractOrderMapper etcContractOrderMapper;

    @Override
    public void insertEtcCar(EtcCarMsg etcCarMsg) throws Exception {
        // 提交车辆审核
        JSONObject jsonObject = EtcService.submitVehInfo(etcCarMsg);
        if (jsonObject.getString("errCode").equals("0")) {
            JSONObject object = (JSONObject) jsonObject.getJSONArray("result").get(0);
            etcCarMsg.setVehId(object.getString("vehId"));

            JSONObject car = EtcService.getVehStatus(etcCarMsg);
            if (car.getString("errCode").equals("0")) {

                etcCarMsg.setVehStatus(car.getJSONObject("result").getInteger("vehStatus"));
                etcCarMsg.setPayStatus(car.getJSONObject("result").getInteger("payStatus"));
                etcCarMsg.setSignStatus(car.getJSONObject("result").getInteger("signStatus"));

                // 添加合同信息
                EtcContractOrder contractOrder = new EtcContractOrder();
                contractOrder.setContractNo(OrderUtil.generateContractNo());
                contractOrder.setCreateTime(new Date());
                contractOrder.setCustId(etcCarMsg.getCustId());
                contractOrder.setProductId(etcCarMsg.getProductId());
                contractOrder.setCardVarietyId(etcCarMsg.getCardVarietyId());
                contractOrder.setProductName(EtcProductEnum.getNameByType(etcCarMsg.getProductId()));
                contractOrder.setCardVarietyName(EtcVarietyEnum.getNameByType(etcCarMsg.getCardVarietyId()));
                contractOrder.setVehId(etcCarMsg.getVehId());
                contractOrder.setPayStatus(1);
                contractOrder.setStatus(1);
                contractOrder.setVehStatus(13);
                contractOrder.setVehStatus(etcCarMsg.getVehStatus());
                contractOrder.setSignStatus(0);
                contractOrder.setBankSign(0);
                contractOrder.setWechatSign(0);
                contractOrder.setNeedSignWechat(0);
                contractOrder.setOpId(etcCarMsg.getUserId());
                contractOrder.setOpName(etcCarMsg.getUserName());

                insertContractOrder(contractOrder);

            }
            etcCarMsg.setExt2(car.toJSONString());

        }
        etcCarMsg.setExt1(jsonObject.getString("errMsg"));
        etcCarMsg.setExt3(jsonObject.toJSONString());

        if (etcCarMsg.getId() != null) {
            etcCarMsgMapper.updateByPrimaryKey(etcCarMsg);
        } else {
            etcCarMsgMapper.insert(etcCarMsg);
        }
    }

    @Override
    public void addEtcCar(EtcCarMsg etcCarMsg) throws Exception {
        etcCarMsgMapper.insert(etcCarMsg);
    }

    @Override
    public void deleteEtcCar(Long id) throws Exception {
        etcCarMsgMapper.deleteByPrimaryKey(id);
    }

    @Override
    public void updateEtcCar(EtcCarMsg etcCarMsg) {
        etcCarMsgMapper.updateByPrimaryKey(etcCarMsg);
    }

    @Override
    public List<EtcCarMsg> getEtcCarList(Map<String, Object> map) {
        EtcCarMsgExample example = new EtcCarMsgExample();
        EtcCarMsgExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map , "userId") != null) {
            criteria.andUserIdEqualTo(MapUtils.getLong(map , "userId"));
        }
        if (MapUtils.getString(map , "vehPlateNo") != null) {
            criteria.andVehPlateNoEqualTo(MapUtils.getString(map , "vehPlateNo"));
        }
        if (MapUtils.getInteger(map , "vehPlateColor") != null) {
            criteria.andVehPlateColorEqualTo(MapUtils.getInteger(map , "vehPlateColor"));
        }
        if (MapUtils.getString(map , "custId") != null) {
            criteria.andCustIdEqualTo(MapUtils.getString(map , "custId"));
        }
        if (MapUtils.getString(map , "status") != null) {
            String[] strings = MapUtils.getString(map, "status").split(",");
            List<Integer> statusList = new ArrayList<>();
            for (String i : strings) {
                statusList.add(Integer.parseInt(i));
            }
            criteria.andVehStatusIn(statusList);
        }

        return etcCarMsgMapper.selectByExample(example);
    }

    @Override
    public EtcCarMsg findEtcCarByMap(Map<String, Object> map) {

        EtcCarMsgExample example = new EtcCarMsgExample();
        EtcCarMsgExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getLong(map , "userId") != null) {
            criteria.andUserIdEqualTo(MapUtils.getLong(map , "userId"));
        }
        if (MapUtils.getString(map , "vehPlateNo") != null) {
            criteria.andVehPlateNoEqualTo(MapUtils.getString(map , "vehPlateNo"));
        }
        if (MapUtils.getInteger(map , "vehPlateColor") != null) {
            criteria.andVehPlateColorEqualTo(MapUtils.getInteger(map , "vehPlateColor"));
        }
        if (MapUtils.getString(map , "custId") != null) {
            criteria.andCustIdEqualTo(MapUtils.getString(map , "custId"));
        }
        if (MapUtils.getString(map , "vehId") != null) {
            criteria.andVehIdEqualTo(MapUtils.getString(map , "vehId"));
        }
        if (MapUtils.getInteger(map , "vehStatus") != null) {
            criteria.andVehStatusNotEqualTo(MapUtils.getInteger(map , "vehStatus"));
        }

        List<EtcCarMsg> list = etcCarMsgMapper.selectByExample(example);

        if (!list.isEmpty()) {
            return list.get(0);
        }

        return null;
    }

    @Override
    public EtcCarMsg findEtcCarById(Long id) {
        return etcCarMsgMapper.selectByPrimaryKey(id);
    }

    @Override
    public void insertContractOrder(EtcContractOrder etcContractOrder) {
        etcContractOrderMapper.insert(etcContractOrder);
    }

    @Override
    public void updateContractOrder(EtcContractOrder etcContractOrder) {
         etcContractOrderMapper.updateByPrimaryKey(etcContractOrder);
    }

    @Override
    public List<EtcContractOrder> getEtcContractOrderList(Map<String, Object> map) {
        EtcContractOrderExample example = new EtcContractOrderExample();
        EtcContractOrderExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getString(map , "phone") != null) {
            criteria.andPhoneEqualTo(MapUtils.getString(map , "phone"));
        }
        if (MapUtils.getInteger(map , "signStatus") != null) {
            criteria.andSignStatusEqualTo(MapUtils.getInteger(map , "signStatus"));
        }
        if (MapUtils.getString(map , "custId") != null) {
            criteria.andCustIdEqualTo(MapUtils.getString(map , "custId"));
        }
        if (MapUtils.getInteger(map , "vehStatus") != null) {
            criteria.andVehStatusEqualTo(MapUtils.getInteger(map , "vehStatus"));
        }

        return etcContractOrderMapper.selectByExample(example);
    }

    @Override
    public EtcContractOrder findContractOrderById(Long id) {
        return etcContractOrderMapper.selectByPrimaryKey(id);
    }
}
