package com.hai.pay.channel.huift;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.utils.HttpsUtils;
import com.hai.config.CommonSysConst;
import com.hai.entity.HighOrder;
import com.hai.entity.HighOrderRefund;
import com.hai.enum_type.OrderStatusEnum;
import com.hai.order.type.OrderPayType;
import com.hai.order.type.OrderProductType;
import com.hai.pay.channel.huift.config.HuiftConfig;
import com.hai.service.HighOrderService;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: TradeService
 * @author: HuRui
 * @date: 2024/4/7
 **/
@Component
public class TradeService {

    @Resource
    private HighOrderService orderService;

    /**
     * 交易-预下单
     * @param order
     * @return
     * @throws Exception
     */
    public JSONObject thirdPreOrder(HighOrder order) throws Exception {
        Map<String,Object> param = new HashMap<>();
        param.put("shopCode", HuiftConfig.shopcode);
        param.put("outTradeNo", order.getOrderNo());
        param.put("transAmt", order.getPayablePrice().multiply(new BigDecimal("100")).intValue());
        // param.put("mobileNbr", order.getMemPhone()); // 用户标识
        param.put("callbackUrl", CommonSysConst.getSysConfig().getHsgDomainName() + "/order/payNotify/huiftPay");
        // param.put("remark", ""); // 备注
        // param.put("outAppId", "");
        param.put("outRedirectPath", CommonSysConst.getSysConfig().getHsgDomainName()+"/phg/#/pages/user/order_list/order_list?tbIndex=-1");
        param.put("sign", HuiftConfig.md5Encode(HuiftConfig.paramSort(param, HuiftConfig.signSecret).getBytes()).toLowerCase());
        JSONObject response = HttpsUtils.doPost(HuiftConfig.reqUrl + "/hfq/v1/thirdPay/thirdPreOrder", JSONObject.toJSONString(param));
        if (response.getString("status").equals("ok")) {
            return response.getJSONObject("data");
        }
        throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR , response.getString("message"));
    }

    /**
     * 查询交易结果
     * @param preOrderNo
     * @return
     * @throws Exception
     */
    public JSONObject thirdPayResult(String preOrderNo) throws Exception {
        Map<String,Object> param = new HashMap<>();
        param.put("shopCode", HuiftConfig.shopcode);
        param.put("preOrderNo", preOrderNo);
        param.put("sign", HuiftConfig.md5Encode(HuiftConfig.paramSort(param, HuiftConfig.signSecret).getBytes()).toLowerCase());
        JSONObject response = HttpsUtils.doPost(HuiftConfig.reqUrl + "/hfq/v1/thirdPay/thirdPayResult", JSONObject.toJSONString(param));
        if (response.getString("status").equals("ok")) {
            return response.getJSONObject("data");
        }
        throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR , response.getString("message"));
    }

    /**
     * 交易退款
     * @param refundOrderNo 退款订单号
     * @param refundPrice  退款金额
     * @param orderNo      订单号
     * @return
     * @throws Exception
     */
    public JSONObject thirdPayRefund(String refundOrderNo, BigDecimal refundPrice, String orderNo) throws Exception {
        // 查询订单
        HighOrder order = orderService.getOrderByOrderNo(orderNo);
        if (order == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未知的的订单");
        }
        if (!order.getOrderStatus().equals(OrderStatusEnum.type2.getType())
                && !order.getOrderStatus().equals(OrderStatusEnum.type3.getType())
                && !order.getOrderStatus().equals(OrderStatusEnum.type7.getType())) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "订单当前状态无法退款");
        }
        if (!order.getPayType().equals(OrderPayType.PAY_TYPE10.getNumber())) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "支付方式错误");
        }

        Map<String,Object> param = new HashMap<>();
        param.put("shopCode", HuiftConfig.shopcode);
        param.put("preOrderNo", order.getPayChannelOrderNo());
        param.put("outRefundNo", refundOrderNo);
        param.put("refundAmt", refundPrice.multiply(new BigDecimal("100")).intValue());
        param.put("sign", HuiftConfig.md5Encode(HuiftConfig.paramSort(param, HuiftConfig.signSecret).getBytes()).toLowerCase());
        JSONObject response = HttpsUtils.doPost(HuiftConfig.reqUrl + "/hfq/v1/thirdPay/thirdPayRefund", JSONObject.toJSONString(param));
        if (response.getString("status").equals("ok")) {
            return response.getJSONObject("data");
        }
        throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR , response.getString("message"));
    }

}
