package com.hai.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.config.*;
import com.hai.entity.*;
import com.hai.enum_type.GasOilPriceStatusEnum;
import com.hai.enum_type.JinZhuJiaYouOilNo;
import com.hai.enum_type.MerchantStoreSourceType;
import com.hai.model.HighMerchantModel;
import com.hai.model.HighMerchantStoreModel;
import com.hai.service.*;
import org.apache.commons.lang3.StringUtils;
import org.bouncycastle.crypto.tls.MACAlgorithm;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service("gasService")
public class HighGasServiceImpl implements HighGasService {

    @Resource
    private ShellGroupService shellGroupService;

    @Resource
    private JinZhuJiaYouService jinZhuJiaYouService;

    @Resource
    private HighMerchantService highMerchantService;

    @Resource
    private HighMerchantStoreService highMerchantStoreService;

    @Resource
    private HighMerchantAccountService merAccountService;

    @Resource
    private HighGasOilPriceService highGasOilPriceService;

    @Resource
    private HighGasOilGunNoService gasOilGunNoService;

    @Resource
    private PayloService payloService;

    @Resource
    private CommonService commonService;

    @Resource
    private HighMerchantStoreService merchantStoreService;

    @Override
    public void getJiaHaoYouAllStation() throws Exception {
        HighMerchantModel merchant = highMerchantService.getDetailByKey("HF0801103821");

        JSONObject pObject = shellGroupService.gasPageQueryAllStation(1, 50);
        JSONObject pageInfo = JSON.parseObject(pObject.getString("pageInfo"), JSONObject.class);

        // 总页数
        Integer totalPageNo = pageInfo.getBigDecimal("totalCount").divide(pageInfo.getBigDecimal("pageSize"),0, BigDecimal.ROUND_CEILING).intValue();
        for (int pageNum = 1; pageNum <= totalPageNo; pageNum++) {

            // 查询加油站列表
            JSONObject respObject = shellGroupService.gasPageQueryAllStation(pageNum, 50);
            JSONArray stationArray = JSONObject.parseObject(respObject.getString("infoList"), JSONArray.class);
            for (Object stationObject : stationArray) {
                JSONObject station = (JSONObject) stationObject;

                // 查询油站
                HighMerchantStore store = highMerchantStoreService.getMerStoreDetailByKey(station.getString("stationCode"));

                if (store != null) {
                    store.setPrestoreType(0);
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("stationCode"));
                    store.setStoreName(station.getString("stationName"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg2());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(station.getString("provinceName"));
                    store.setAddress(station.getString("stationAddress"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("ABLE")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setUpdateTime(new Date());
                    highMerchantStoreService.updateMerchantStoreDetail(store);

                    gasOilGunNoService.cleanGunNo(store.getId());

                    JSONArray oilPriceList = station.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        // 查询门店油号
                        HighGasOilPrice highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilPriceObject.getString("goodsCode"));
                        if (highGasOilPrice == null) {
                            highGasOilPrice = new HighGasOilPrice();
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                            highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                            highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPreferentialMargin(new BigDecimal("0"));
                            // 油品类型  1:汽油:2:柴油;3:天然气
                            if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                                highGasOilPrice.setOilType(1);
                                highGasOilPrice.setOilTypeName("汽油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                                highGasOilPrice.setOilType(2);
                                highGasOilPrice.setOilTypeName("柴油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                                highGasOilPrice.setOilType(3);
                                highGasOilPrice.setOilTypeName("天然气");
                            }
                            highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                            JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                            for (Object o : oilGunNoList) {
                                HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                if (gasOilGunNo == null) {
                                    gasOilGunNo = new HighGasOilGunNo();
                                    gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                    gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                    gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                    gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                    gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                    gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                    gasOilGunNo.setGunNo(o.toString());
                                    gasOilGunNo.setStatus(1);
                                    gasOilGunNoService.editGunNo(gasOilGunNo);
                                }
                            }

                        } else {
                            highGasOilPrice.setPreferentialMargin(highGasOilPrice.getPreferentialMargin()!=null?highGasOilPrice.getPreferentialMargin():new BigDecimal("0"));
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                            highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                            highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount").subtract(highGasOilPrice.getPreferentialMargin()));
                            highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount"));

                            // 油品类型  1:汽油:2:柴油;3:天然气
                            if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                                highGasOilPrice.setOilType(1);
                                highGasOilPrice.setOilTypeName("汽油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                                highGasOilPrice.setOilType(2);
                                highGasOilPrice.setOilTypeName("柴油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                                highGasOilPrice.setOilType(3);
                                highGasOilPrice.setOilTypeName("天然气");
                            }
                            highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                            JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                            for (Object o : oilGunNoList) {
                                HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                if (gasOilGunNo == null) {
                                    gasOilGunNo = new HighGasOilGunNo();
                                    gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                    gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                    gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                    gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                    gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                    gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                    gasOilGunNo.setGunNo(o.toString());
                                    gasOilGunNo.setStatus(1);
                                    gasOilGunNoService.editGunNo(gasOilGunNo);
                                }
                            }
                        }
                    }
                } else {
                    store = new HighMerchantStore();
                    store.setPrestoreType(0);
                    store.setType(1);
                    store.setSourceType(MerchantStoreSourceType.type3.getNumber());
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("stationCode"));
                    store.setStoreName(station.getString("stationName"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg2());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(station.getString("provinceName"));
                    store.setAddress(station.getString("stationAddress"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("ABLE")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setCreateTime(new Date());
                    store.setUpdateTime(new Date());

                    HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                    BeanUtils.copyProperties(store, merchantStoreModel);
                    highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                    JSONArray oilPriceList = station.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        HighGasOilPrice highGasOilPrice = new HighGasOilPrice();
                        highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                        highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                        highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                        highGasOilPrice.setPreferentialMargin(new BigDecimal("0"));
                        highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                        highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                        highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                        highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("listedPrice").getBigDecimal("amount"));

                        // 油品类型  1:汽油:2:柴油;3:天然气
                        if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                            highGasOilPrice.setOilType(1);
                            highGasOilPrice.setOilTypeName("汽油");
                        } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                            highGasOilPrice.setOilType(2);
                            highGasOilPrice.setOilTypeName("柴油");
                        } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                            highGasOilPrice.setOilType(3);
                            highGasOilPrice.setOilTypeName("天然气");
                        }
                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                        JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                        for (Object o : oilGunNoList) {
                            HighGasOilGunNo gasOilGunNo = new HighGasOilGunNo();
                            gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                            gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                            gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                            gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                            gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                            gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                            gasOilGunNo.setGunNo(o.toString());
                            gasOilGunNo.setStatus(1);
                            gasOilGunNoService.editGunNo(gasOilGunNo);
                        }
                    }
                }
            }
        }

        // 正式环境测试油站，默认屏蔽
        HighMerchantStore store = highMerchantStoreService.getMerStoreDetailByKey("1001");
        if (store != null) {
            store.setStatus(0);
            highMerchantStoreService.updateMerchantStoreDetail(store);
        }
    }

    @Override
    public void getPayloAllStation() throws Exception {
        HighMerchantModel merchant = highMerchantService.getDetailByKey("HF0801103822");

        JSONObject pObject = payloService.ycShellPageQueryAllStation(1, 50);
        JSONObject pageInfo = JSON.parseObject(pObject.getString("pageInfo"), JSONObject.class);

        // 总页数
        Integer totalPageNo = pageInfo.getBigDecimal("totalCount").divide(pageInfo.getBigDecimal("pageSize"),0, BigDecimal.ROUND_CEILING).intValue();
        for (int pageNum = 1; pageNum <= totalPageNo; pageNum++) {
            // 查询加油站列表
            JSONObject respObject = payloService.ycShellPageQueryAllStation(pageNum, 50);
            JSONArray stationArray = JSONObject.parseObject(respObject.getString("infoList"), JSONArray.class);
            for (Object stationObject : stationArray) {
                JSONObject station = (JSONObject) stationObject;

                // 查询油站
                HighMerchantStore store = highMerchantStoreService.getMerStoreDetailByKey(station.getString("stationCode"));

                if (store != null) {
                    store.setPrestoreType(0);
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("stationCode"));
                    store.setStoreName(station.getString("stationName"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg2());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(station.getString("provinceName"));
                    store.setAddress(station.getString("stationAddress"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("ABLE")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setUpdateTime(new Date());
                    highMerchantStoreService.updateMerchantStoreDetail(store);

                    gasOilGunNoService.cleanGunNo(store.getId());

                    JSONArray oilPriceList = station.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        // 查询门店油号
                        HighGasOilPrice highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilPriceObject.getString("goodsCode"));
                        if (highGasOilPrice == null) {
                            highGasOilPrice = new HighGasOilPrice();
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                            highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                            highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));

                            // 油品类型  1:汽油:2:柴油;3:天然气
                            if (StringUtils.isNotBlank(oilPriceObject.getString("goodsGroupType"))) {
                                if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                                    highGasOilPrice.setOilType(1);
                                    highGasOilPrice.setOilTypeName("汽油");
                                } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                                    highGasOilPrice.setOilType(2);
                                    highGasOilPrice.setOilTypeName("柴油");
                                } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                                    highGasOilPrice.setOilType(3);
                                    highGasOilPrice.setOilTypeName("天然气");
                                }
                                highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                            }

                            JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                            for (Object o : oilGunNoList) {
                                HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                if (gasOilGunNo == null) {
                                    gasOilGunNo = new HighGasOilGunNo();
                                    gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                    gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                    gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                    gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                    gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                    gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                    gasOilGunNo.setGunNo(o.toString());
                                    gasOilGunNo.setStatus(1);
                                    gasOilGunNoService.editGunNo(gasOilGunNo);
                                }
                            }

                        } else {
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                            highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                            highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));

                            // 油品类型  1:汽油:2:柴油;3:天然气
                            if (StringUtils.isNotBlank(oilPriceObject.getString("goodsGroupType"))) {
                                if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                                    highGasOilPrice.setOilType(1);
                                    highGasOilPrice.setOilTypeName("汽油");
                                } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                                    highGasOilPrice.setOilType(2);
                                    highGasOilPrice.setOilTypeName("柴油");
                                } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                                    highGasOilPrice.setOilType(3);
                                    highGasOilPrice.setOilTypeName("天然气");
                                }
                                highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                            }

                            JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                            for (Object o : oilGunNoList) {
                                HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                if (gasOilGunNo == null) {
                                    gasOilGunNo = new HighGasOilGunNo();
                                    gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                    gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                    gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                    gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                    gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                    gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                    gasOilGunNo.setGunNo(o.toString());
                                    gasOilGunNo.setStatus(1);
                                    gasOilGunNoService.editGunNo(gasOilGunNo);
                                }
                            }
                        }
                    }
                } else {
                    store = new HighMerchantStore();
                    store.setPrestoreType(0);
                    store.setType(1);
                    store.setSourceType(MerchantStoreSourceType.type5.getNumber());
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("stationCode"));
                    store.setStoreName(station.getString("stationName"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg2());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(station.getString("provinceName"));
                    store.setAddress(station.getString("stationAddress"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("ABLE")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setCreateTime(new Date());
                    store.setUpdateTime(new Date());

                    HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                    BeanUtils.copyProperties(store, merchantStoreModel);
                    highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                    JSONArray oilPriceList = station.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        HighGasOilPrice highGasOilPrice = new HighGasOilPrice();
                        highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                        highGasOilPrice.setOilNo(oilPriceObject.getString("goodsCode"));
                        highGasOilPrice.setOilNoName(oilPriceObject.getString("goodsCode") + "#");
                        highGasOilPrice.setPreferentialMargin(new BigDecimal("0"));
                        highGasOilPrice.setGasStationDrop(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount").subtract(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount")));
                        highGasOilPrice.setPriceVip(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                        highGasOilPrice.setPriceGun(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));
                        highGasOilPrice.setPriceOfficial(oilPriceObject.getJSONObject("goodsPrice").getBigDecimal("amount"));

                        // 油品类型  1:汽油:2:柴油;3:天然气
                        if (StringUtils.isNotBlank(oilPriceObject.getString("goodsGroupType"))) {
                            if (oilPriceObject.getString("goodsGroupType").equals("GASOLINE")) {
                                highGasOilPrice.setOilType(1);
                                highGasOilPrice.setOilTypeName("汽油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("DIESEL_OIL")) {
                                highGasOilPrice.setOilType(2);
                                highGasOilPrice.setOilTypeName("柴油");
                            } else if (oilPriceObject.getString("goodsGroupType").equals("NATURAL_GAS")) {
                                highGasOilPrice.setOilType(3);
                                highGasOilPrice.setOilTypeName("天然气");
                            }
                            highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                        }

                        JSONArray oilGunNoList = oilPriceObject.getJSONArray("oilGunNoList");
                        for (Object o : oilGunNoList) {
                            HighGasOilGunNo gasOilGunNo = new HighGasOilGunNo();
                            gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                            gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                            gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                            gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                            gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                            gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                            gasOilGunNo.setGunNo(o.toString());
                            gasOilGunNo.setStatus(1);
                            gasOilGunNoService.editGunNo(gasOilGunNo);
                        }
                    }
                }
            }
        }


        // 正式环境测试油站，默认屏蔽
        HighMerchantStore store = highMerchantStoreService.getMerStoreDetailByKey("8888");
        if (store != null) {
            store.setStatus(0);
            highMerchantStoreService.updateMerchantStoreDetail(store);
        }
    }

    @Override
    public void getDianAllStation() throws Exception {
        HighMerchantModel merchant = highMerchantService.getMerchantById(39L);
        if (merchant == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未找到商户");
        }
        JSONObject jsonObjectP = TuanYouConfig.queryGasInfoListByPage(1, 1000);
        JSONObject resultObjectP = jsonObjectP.getObject("result", JSONObject.class);

        for (int i = 1; i <= resultObjectP.getInteger("totalPageNum").intValue();i++) {
            JSONObject jsonObject = TuanYouConfig.queryGasInfoListByPage(i, 1000);
            JSONObject resultObject = jsonObject.getObject("result", JSONObject.class);
            JSONArray jsonArray = resultObject.getJSONArray("gasInfoList");
            HighMerchantStore highMerchantStore;
            HighGasOilPrice highGasOilPrice;
            for (Object gasObject : jsonArray) {
                JSONObject object = JSONObject.parseObject(JSONObject.toJSONString(gasObject));
                HighMerchantStoreModel store = highMerchantStoreService.getMerchantStoreByKey(object.getString("gasId"));
                JSONArray gasGunList = object.getJSONArray("gasGunList");
                if (store != null) {
                    store.setType(1);
                    store.setSourceType(2);
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(object.getString("gasId"));
                    store.setStoreName(object.getString("gasName"));
                    store.setStoreLogo(object.getString("gasLogoSmall"));
                    store.setRegionId(object.getLong("provinceCode"));
                    store.setRegionName(object.getString("provinceName"));
                    store.setAddress(object.getString("gasAddress"));
                    store.setLongitude(object.getString("gasAddressLongitude"));
                    store.setLatitude(object.getString("gasAddressLatitude"));
                    store.setStatus(object.getInteger("gasStatus"));
                    store.setPrestoreType(0);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setUpdateTime(new Date());
                    store.setExt1(object.getString("gasSourceId"));
                    highMerchantStoreService.updateMerchantStoreDetail(store);

                    JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        // 查询门店油号
                        highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilPriceObject.getString("oilNo"));
                        if (highGasOilPrice == null) {
                            highGasOilPrice = new HighGasOilPrice();
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                            highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("priceVip"));
                            highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                            highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                            highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                            highGasOilPrice.setStatus(GasOilPriceStatusEnum.status1.getStatus());
                        } else {
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                            highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("priceVip"));
                            highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                            highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                            highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                            highGasOilPrice.setStatus(GasOilPriceStatusEnum.status1.getStatus());
                        }
                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                        for (Object o : gasGunList) {
                            JSONObject gunNoObject = (JSONObject) o;
                            HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), gunNoObject.getString("gunNo"));
                            if (gasOilGunNo == null) {
                                gasOilGunNo = new HighGasOilGunNo();
                                gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                gasOilGunNo.setGunNo(gunNoObject.getString("gunNo"));
                                gasOilGunNo.setStatus(1);
                                gasOilGunNoService.editGunNo(gasOilGunNo);
                            }
                        }
                    }
                } else {
                    highMerchantStore = new HighMerchantStore();
                    highMerchantStore.setType(1);
                    highMerchantStore.setSourceType(2);
                    highMerchantStore.setMerchantId(merchant.getId());
                    highMerchantStore.setCompanyId(merchant.getCompanyId());
                    highMerchantStore.setStoreKey(object.getString("gasId"));
                    highMerchantStore.setStoreName(object.getString("gasName"));
                    highMerchantStore.setStoreLogo(object.getString("gasLogoSmall"));
                    highMerchantStore.setRegionId(object.getLong("provinceCode"));
                    highMerchantStore.setRegionName(object.getString("provinceName"));
                    highMerchantStore.setAddress(object.getString("gasAddress"));
                    highMerchantStore.setLongitude(object.getString("gasAddressLongitude"));
                    highMerchantStore.setLatitude(object.getString("gasAddressLatitude"));
                    highMerchantStore.setStatus(1);
                    highMerchantStore.setPrestoreType(0);
                    highMerchantStore.setOperatorId(0L);
                    highMerchantStore.setOperatorName("系统创建");
                    highMerchantStore.setCreateTime(new Date());
                    highMerchantStore.setUpdateTime(new Date());
                    highMerchantStore.setExt1(object.getString("gasSourceId"));
                    HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                    BeanUtils.copyProperties(highMerchantStore, merchantStoreModel);
                    highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                    JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        highGasOilPrice = new HighGasOilPrice();
                        highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                        highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                        highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                        highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("priceVip"));
                        highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceGun"));
                        highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                        highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                        highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                        highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                        highGasOilPrice.setStatus(GasOilPriceStatusEnum.status1.getStatus());
                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                        for (Object o : gasGunList) {
                            JSONObject gunNoObject = (JSONObject) o;
                            HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), gunNoObject.getString("gunNo"));
                            if (gasOilGunNo == null) {
                                gasOilGunNo = new HighGasOilGunNo();
                                gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                gasOilGunNo.setGunNo(gunNoObject.getString("gunNo"));
                                gasOilGunNo.setStatus(1);
                                gasOilGunNoService.editGunNo(gasOilGunNo);
                            }
                        }
                    }
                }
            }
        }

    }

    @Override
    public void getJinZhuAllStation() throws Exception {
        HighMerchantModel merchant = highMerchantService.getDetailByKey("HF0802153624");

        JSONObject pageInfo = jinZhuJiaYouService.getStationListPage(0, 50).getJSONObject("data");

        // 总页数
        for (int pageNum = 0; pageNum < pageInfo.getInteger("totalPages"); pageNum++) {
            // 查询加油站列表
            JSONObject respObject = jinZhuJiaYouService.getStationListPage(pageNum, 50).getJSONObject("data");
            JSONArray stationArray = respObject.getJSONArray("content");

            for (Object stationObject : stationArray) {
                JSONObject station = (JSONObject) stationObject;

                // 查询油站
                HighMerchantStore store = highMerchantStoreService.getMerStoreDetailByKey(station.getString("code"));

                // 查询区域
                SecRegion region = commonService.getRegionsById(station.getLong("provinceId"));

                if (store != null) {
                    store.setPrestoreType(0);
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("code"));
                    store.setStoreName(station.getString("name"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(region!=null?region.getRegionName():null);
                    store.setAddress(station.getString("address"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("VALID")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setUpdateTime(new Date());
                    highMerchantStoreService.updateMerchantStoreDetail(store);

                    gasOilGunNoService.cleanGunNo(store.getId());

                    JSONArray oilPriceList = station.getJSONArray("oils");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));

                        // 查询油号
                        JinZhuJiaYouOilNo oilNo = JinZhuJiaYouOilNo.getDataByCode(oilPriceObject.getString("oilNo"));
                        if (oilNo != null) {
                            // 查询门店油号
                            HighGasOilPrice highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilNo.getOilNo());
                            if (highGasOilPrice == null) {
                                highGasOilPrice = new HighGasOilPrice();
                                highGasOilPrice.setMerchantStoreId(store.getId());
                                highGasOilPrice.setOilType(oilNo!=null?oilNo.getOilType():null);
                                highGasOilPrice.setOilTypeName(oilNo!=null?oilNo.getOilTypeName():null);
                                highGasOilPrice.setOilNo(oilNo!=null?oilNo.getOilNo():null);
                                highGasOilPrice.setOilNoName(oilNo!=null?oilNo.getOilNoName():null);

                                highGasOilPrice.setPreferentialMargin(new BigDecimal("0"));
                                highGasOilPrice.setGasStationDrop(oilPriceObject.getBigDecimal("guidancePrice").subtract(oilPriceObject.getBigDecimal("listingPrice")));
                                highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("merchantStrikePrice"));
                                highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("listingPrice"));
                                highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("listingPrice"));
                                highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("guidancePrice"));
                                highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                                JSONArray oilGunNoList = oilPriceObject.getJSONArray("guns");
                                for (Object o : oilGunNoList) {
                                    HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                    if (gasOilGunNo == null) {
                                        gasOilGunNo = new HighGasOilGunNo();
                                        gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                        gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                        gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                        gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                        gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                        gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                        gasOilGunNo.setGunNo(o.toString());
                                        gasOilGunNo.setStatus(1);
                                        gasOilGunNoService.editGunNo(gasOilGunNo);
                                    }
                                }

                            } else {
                                highGasOilPrice.setGasStationDrop(oilPriceObject.getBigDecimal("guidancePrice").subtract(oilPriceObject.getBigDecimal("listingPrice")));
                                highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("merchantStrikePrice"));
                                highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("listingPrice"));
                                highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("listingPrice"));
                                highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("guidancePrice"));
                                highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                                JSONArray oilGunNoList = oilPriceObject.getJSONArray("guns");
                                for (Object o : oilGunNoList) {
                                    HighGasOilGunNo gasOilGunNo = gasOilGunNoService.getDetailByStoreAndGunNo(highGasOilPrice.getMerchantStoreId(), o.toString());
                                    if (gasOilGunNo == null) {
                                        gasOilGunNo = new HighGasOilGunNo();
                                        gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                                        gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                                        gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                                        gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                                        gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                                        gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                                        gasOilGunNo.setGunNo(o.toString());
                                        gasOilGunNo.setStatus(1);
                                        gasOilGunNoService.editGunNo(gasOilGunNo);
                                    }
                                }
                            }
                        }
                    }
                } else {
                    store = new HighMerchantStore();
                    store.setPrestoreType(0);
                    store.setType(1);
                    store.setSourceType(MerchantStoreSourceType.type4.getNumber());
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(station.getString("code"));
                    store.setStoreName(station.getString("name"));
                    store.setStoreLogo(CommonSysConst.getSysConfig().getGasDefaultOilStationImg());
                    store.setRegionId(station.getLong("provinceId"));
                    store.setRegionName(station.getString("provinceName"));
                    store.setAddress(station.getString("address"));
                    store.setLongitude(station.getString("longitude"));
                    store.setLatitude(station.getString("latitude"));
                    store.setStatus(station.getString("status").equals("VALID")?1:2);
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setCreateTime(new Date());
                    store.setUpdateTime(new Date());

                    HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                    BeanUtils.copyProperties(store, merchantStoreModel);
                    highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                    JSONArray oilPriceList = station.getJSONArray("oils");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));

                        // 查询油号
                        JinZhuJiaYouOilNo oilNo = JinZhuJiaYouOilNo.getDataByCode(oilPriceObject.getString("oilNo"));

                        HighGasOilPrice highGasOilPrice = new HighGasOilPrice();
                        highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                        highGasOilPrice.setOilType(oilNo!=null?oilNo.getOilType():null);
                        highGasOilPrice.setOilTypeName(oilNo!=null?oilNo.getOilTypeName():null);
                        highGasOilPrice.setOilNo(oilNo!=null?oilNo.getOilNo():null);
                        highGasOilPrice.setOilNoName(oilNo!=null?oilNo.getOilNoName():null);

                        highGasOilPrice.setPreferentialMargin(new BigDecimal("0"));
                        highGasOilPrice.setGasStationDrop(oilPriceObject.getBigDecimal("guidancePrice").subtract(oilPriceObject.getBigDecimal("listingPrice")));
                        highGasOilPrice.setPriceCost(oilPriceObject.getBigDecimal("merchantStrikePrice"));
                        highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("listingPrice"));
                        highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("listingPrice"));
                        highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("guidancePrice"));

                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);

                        JSONArray oilGunNoList = oilPriceObject.getJSONArray("guns");
                        for (Object o : oilGunNoList) {
                            HighGasOilGunNo gasOilGunNo = new HighGasOilGunNo();
                            gasOilGunNo.setGasOilPriceId(highGasOilPrice.getId());
                            gasOilGunNo.setStoreId(highGasOilPrice.getMerchantStoreId());
                            gasOilGunNo.setOilNo(highGasOilPrice.getOilNo());
                            gasOilGunNo.setOilNoName(highGasOilPrice.getOilNoName());
                            gasOilGunNo.setOilType(highGasOilPrice.getOilType());
                            gasOilGunNo.setOilTypeName(highGasOilPrice.getOilTypeName());
                            gasOilGunNo.setGunNo(o.toString());
                            gasOilGunNo.setStatus(1);
                            gasOilGunNoService.editGunNo(gasOilGunNo);
                        }
                    }
                }
            }

        }
    }

    @Override
    public BigDecimal getMerPriceByMerId(Long merId) {
        BigDecimal account = new BigDecimal("0");
        // 查询账号余额
        HighMerchantAccount merAccount = merAccountService.getMerAccountDetail(merId);
        if (merAccount != null) {
            account = merAccount.getAmounts().subtract(merAccountService.countMerGasOilAmount(merId));
        }
        return account;
    }

    @Override
    public void deleteOilNo() {
        Map<String , Object> map = new HashMap<>();
        map.put("oilType" , 2);
        List<HighGasOilGunNo> list = gasOilGunNoService.getGunNoList(map);

        for (HighGasOilGunNo gasOilGunNo : list) {
            gasOilGunNo.setStatus(0);
            gasOilGunNoService.editGunNo(gasOilGunNo);
        }

        List<HighGasOilPrice> gasOilPriceList = highGasOilPriceService.getGasOilPriceList(map);
        for (HighGasOilPrice gasOilPrice : gasOilPriceList) {
            gasOilPrice.setStatus(0);
            highGasOilPriceService.editGasOilPrice(gasOilPrice);
        }

        Map<String, Object> param = new HashMap<>();
        param.put("sourceType", 2);
        param.put("regionId", "500000");
        param.put("storeName", "壳牌");
        param.put("status", 1);
        List<HighMerchantStore> merchantStoreList = merchantStoreService.getMerchantStoreList(param);

        for (HighMerchantStore merchantStore : merchantStoreList) {
            merchantStore.setUpdateTime(new Date());
            merchantStore.setStatus(0);
            merchantStoreService.updateMerchantStoreDetail(merchantStore);
        }


    }


}
