package com.v1.controller.business;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.config.QianZhuConfig;
import com.hai.entity.*;
import com.hai.model.ResponseData;
import com.hai.openApi.config.PriceComputeConfig;
import com.hai.openApi.service.ApiMchProductService;
import com.hai.order.type.OrderProductType;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value = "/discount")
@Api(value = "优惠券业务")
public class DiscountController {

    private static Logger log = LoggerFactory.getLogger(KfcController.class);

    @Resource
    private ApiMerchantsService apiMerchantsService;

    @Resource
    private SecConfigService secConfigService;

    @Resource
    private ApiIpAddressService apiIpAddressService;

    @Resource
    private HighDiscountPackageService highDiscountPackageService;

    @Resource
    private HighUserService highUserService;

    @Resource
    private HighDiscountUserRelService highDiscountUserRelService;

    @RequestMapping(value = "/presentDiscount", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "赠送优惠券")
    public ResponseData presentDiscount(@RequestBody JSONObject object , HttpServletRequest request ) {
        try {

            String ip = "";
            // 有的user可能使用代理，为处理用户使用代理的情况，使用x-forwarded-for
            if  (request.getHeader("x-forwarded-for") == null)  {
                ip = request.getRemoteAddr();
            }  else  {
                ip = request.getHeader("x-forwarded-for");
            }

            if (!apiIpAddressService.validationIpAddressLegal(object.getString("merchId") , ip)) {
                log.error("getRechargeProduct error!", "IP不在白名单");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.IP_ERROR, "，请联系管理人员！");
            }

            if (
                    StringUtils.isBlank(object.getString("merchId")) ||
                            StringUtils.isBlank(object.getString("packageId")) ||
                            StringUtils.isBlank(object.getString("phone")) ||
                            StringUtils.isBlank(object.getString("sign"))
            ) {
                log.error("getRechargeProduct error!", "请求参数校验失败！");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR);
            }

            ApiMerchants apiMerchants = apiMerchantsService.findByMchId(object.getString("merchId"));

            if (apiMerchants == null) {
                log.error("getRechargeProduct error!", "帐户号错误！");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_NOT_EXIST);
            }

            Map<String , Object> map = new HashMap<>();
            map.put("apiKey" , apiMerchants.getApiKey());
            map.put("packageId" , object.getString("packageId"));
            map.put("phone" , object.getString("phone"));
            map.put("merchId" , object.getString("merchId"));


            if (!secConfigService.isSignVerify(map , object.getString("sign"))) {
                log.error("getRechargeProduct error!", "签名校验失败！");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SIGN_VERIFY);
            }

            highDiscountPackageService.giveAway(object.getLong("packageId"), object.getString("phone") , 2 , object.getString("merchId"));

            return ResponseMsgUtil.success("赠送成功");

        } catch (Exception e) {
            log.error("HighOpenApiController --> getRechargeProduct() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getDiscountPackage", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询可用优惠券包")
    public ResponseData getDiscountPackage(@RequestParam(name = "type", required = true) Integer type , HttpServletRequest request) {
        try {

            Map<String, Object> map = new HashMap<>();
            map.put("usingAttribution", type);
            map.put("status" , 1);

            List<JSONObject> list = new ArrayList<>();

            List<HighDiscountPackage> discountPackages = highDiscountPackageService.getDiscountPackageList(map);

            for (HighDiscountPackage discountPackage : discountPackages) {
                JSONObject object = new JSONObject();
                object.put("packageDetail" , highDiscountPackageService.findDiscountPackageById(discountPackage.getId()));
                object.put("discountPackage" , discountPackage);
                list.add(object);
            }

            return ResponseMsgUtil.success(list);

        } catch (Exception e) {
            log.error("HighUserCardController --> oilCardRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getUserDiscountList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询用户优惠券")
    public ResponseData getUserDiscountList(@RequestParam(name = "phone", required = true) String phone , HttpServletRequest request) {
        try {

            HighUser user = highUserService.findByPhone(phone);

            if (user == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR , "用户不存在！");
            }

            Map<String,Object> map = new HashMap<>();
            map.put("userId", user.getId());

            return ResponseMsgUtil.success(highDiscountUserRelService.getDiscountList(map));

        } catch (Exception e) {
            log.error("HighUserCardController --> oilCardRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
